==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesSshSshArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSH Configuration
 * @property publicKeys PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
 */
public data class VirtualMachinePropertiesSshSshArgs(
    public val publicKeys: Output<List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs.builder()
            .publicKeys(
                publicKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachinePropertiesSshSshArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesSshSshArgsBuilder internal constructor() {
    private var publicKeys: Output<List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>? = null

    /**
     * @param value PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("ienpgrmcrxirfhse")
    public suspend
    fun publicKeys(`value`: Output<List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>) {
        this.publicKeys = value
    }

    @JvmName("figcmnknlopgdnus")
    public suspend fun publicKeys(
        vararg
        values: Output<VirtualMachinePropertiesPublicKeysPublicKeysArgs>,
    ) {
        this.publicKeys = Output.all(values.asList())
    }

    /**
     * @param values PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("hykxfqnnkdvupcgp")
    public suspend
    fun publicKeys(values: List<Output<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>) {
        this.publicKeys = Output.all(values)
    }

    /**
     * @param value PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("omfmjbfegasfbuqv")
    public suspend fun publicKeys(`value`: List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    /**
     * @param argument PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("dkoxfnwtlkyqfkef")
    public suspend
    fun publicKeys(argument: List<suspend VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("beoqonuundarluqe")
    public suspend fun publicKeys(
        vararg
        argument: suspend VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("prpgaugeirhtnkjo")
    public suspend
    fun publicKeys(argument: suspend VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param values PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("lpxmsobulqwkehns")
    public suspend fun publicKeys(vararg values: VirtualMachinePropertiesPublicKeysPublicKeysArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    internal fun build(): VirtualMachinePropertiesSshSshArgs = VirtualMachinePropertiesSshSshArgs(
        publicKeys = publicKeys,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesSshSshArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSH Configuration
 * @property publicKeys PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
 */
public data class VirtualMachinePropertiesSshSshArgs(
    public val publicKeys: Output<List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesSshSshArgs.builder()
            .publicKeys(
                publicKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachinePropertiesSshSshArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesSshSshArgsBuilder internal constructor() {
    private var publicKeys: Output<List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>? = null

    /**
     * @param value PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("eftrvhnjkvjfluek")
    public suspend
    fun publicKeys(`value`: Output<List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>) {
        this.publicKeys = value
    }

    @JvmName("klgsimraixpctamy")
    public suspend fun publicKeys(
        vararg
        values: Output<VirtualMachinePropertiesPublicKeysPublicKeysArgs>,
    ) {
        this.publicKeys = Output.all(values.asList())
    }

    /**
     * @param values PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("dswmykvmedpjwpxa")
    public suspend
    fun publicKeys(values: List<Output<VirtualMachinePropertiesPublicKeysPublicKeysArgs>>) {
        this.publicKeys = Output.all(values)
    }

    /**
     * @param value PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("goejriehgkbryrhp")
    public suspend fun publicKeys(`value`: List<VirtualMachinePropertiesPublicKeysPublicKeysArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    /**
     * @param argument PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("feayyhudcgxxfflj")
    public suspend
    fun publicKeys(argument: List<suspend VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("jtdhkdbmbwavtqxt")
    public suspend fun publicKeys(
        vararg
        argument: suspend VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("wikjlkaauivnxojs")
    public suspend
    fun publicKeys(argument: suspend VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachinePropertiesPublicKeysPublicKeysArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param values PublicKeys - The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("nuhnqhdnttpgklku")
    public suspend fun publicKeys(vararg values: VirtualMachinePropertiesPublicKeysPublicKeysArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    internal fun build(): VirtualMachinePropertiesSshSshArgs = VirtualMachinePropertiesSshSshArgs(
        publicKeys = publicKeys,
    )
}
